==> knative-model-4.12.0-sources.jar: annotations/io/fabric8/knative/eventing/contrib/kafka/v1beta1/KafkaBindingBuilder.java <==
package io.fabric8.knative.eventing.contrib.kafka.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class KafkaBindingBuilder extends KafkaBindingFluentImpl<KafkaBindingBuilder> implements VisitableBuilder<KafkaBinding,KafkaBindingBuilder> {

    KafkaBindingFluent<?> fluent;
    Boolean validationEnabled;

    public KafkaBindingBuilder() { 
        this(true);
    }


    public KafkaBindingBuilder(Boolean validationEnabled) { 
        this(new KafkaBinding(), validationEnabled);
    }


    public KafkaBindingBuilder(KafkaBindingFluent<?> fluent) { 
        this(fluent, true);
    }


    public KafkaBindingBuilder(KafkaBindingFluent<?> fluent,Boolean validationEnabled) { 
        this(fluent, new KafkaBinding(), validationEnabled);
    }


    public KafkaBindingBuilder(KafkaBindingFluent<?> fluent,KafkaBinding instance) { 
        this(fluent, instance, true);
    }


    public KafkaBindingBuilder(KafkaBindingFluent<?> fluent,KafkaBinding instance,Boolean validationEnabled) { 
        this.fluent = fluent; 
        fluent.withApiVersion(instance.getApiVersion()); 
        fluent.withKind(instance.getKind()); 
        fluent.withMetadata(instance.getMetadata()); 
        fluent.withSpec(instance.getSpec()); 
        fluent.withStatus(instance.getStatus()); 
        this.validationEnabled = validationEnabled; 
    }


    public KafkaBindingBuilder(KafkaBinding instance) { 
        this(instance,true);
    }


    public KafkaBindingBuilder(KafkaBinding instance,Boolean validationEnabled) { 
        this.fluent = this; 
        this.withApiVersion(instance.getApiVersion()); 
        this.withKind(instance.getKind()); 
        this.withMetadata(instance.getMetadata()); 
        this.withSpec(instance.getSpec()); 
        this.withStatus(instance.getStatus()); 
        this.validationEnabled = validationEnabled; 
    }


    public KafkaBinding build() {
        KafkaBinding buildable = new KafkaBinding(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        KafkaBindingBuilder that = (KafkaBindingBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> knative-model-5.2.0-sources.jar: annotations/io/fabric8/knative/eventing/contrib/kafka/v1beta1/KafkaBindingBuilder.java <==
package io.fabric8.knative.eventing.contrib.kafka.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class KafkaBindingBuilder extends KafkaBindingFluentImpl<KafkaBindingBuilder> implements VisitableBuilder<KafkaBinding,KafkaBindingBuilder> {

    KafkaBindingFluent<?> fluent;
    Boolean validationEnabled;

    public KafkaBindingBuilder() {
        this(true);
    }

    public KafkaBindingBuilder(Boolean validationEnabled) {
        this(new KafkaBinding(), validationEnabled);
    }

    public KafkaBindingBuilder(KafkaBindingFluent<?> fluent) {
        this(fluent, true);
    }

    public KafkaBindingBuilder(KafkaBindingFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new KafkaBinding(), validationEnabled);
    }

    public KafkaBindingBuilder(KafkaBindingFluent<?> fluent,KafkaBinding instance) {
        this(fluent, instance, true);
    }

    public KafkaBindingBuilder(KafkaBindingFluent<?> fluent,KafkaBinding instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withApiVersion(instance.getApiVersion()); 
        fluent.withKind(instance.getKind()); 
        fluent.withMetadata(instance.getMetadata()); 
        fluent.withSpec(instance.getSpec()); 
        fluent.withStatus(instance.getStatus()); 
        this.validationEnabled = validationEnabled; 
    }

    public KafkaBindingBuilder(KafkaBinding instance) {
        this(instance,true);
    }

    public KafkaBindingBuilder(KafkaBinding instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withApiVersion(instance.getApiVersion()); 
        this.withKind(instance.getKind()); 
        this.withMetadata(instance.getMetadata()); 
        this.withSpec(instance.getSpec()); 
        this.withStatus(instance.getStatus()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.knative.eventing.contrib.kafka.v1beta1.EditableKafkaBinding build() {
        EditableKafkaBinding buildable = new EditableKafkaBinding(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        KafkaBindingBuilder that = (KafkaBindingBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
